@@ -42,3 +42,32 @@ def euler_from_quaternion(x, y, z, w):
     t4 = +1.0 - 2.0 * (y * y + z * z)
     yaw_z = math.atan2(t3, t4)
     return roll_x, pitch_y, yaw_z # in radians
+
+
+def standardize_ranges(ranges, angles):
+    angles = angles[np.isfinite(ranges)] # delete 'inf'
+    ranges = ranges[np.isfinite(ranges)]
+    angles = wrap_to_pi(angles) # angles should take values in [-pi, pi]
+    return [ranges, angles]
+
+
+def ranges2xy(ranges, angles):
+    y = np.sin(angles)*ranges
+    x = np.cos(angles)*ranges
+    return [x, y]
+
+
+def xy2ranges(x, y):
+    ranges = np.sqrt(np.square(x) + np.square(y))
+    angles = np.arctan2(y,x)
+    return [ranges, angles]
+
+
+# same?
+def convert_polar_scan_to_cartesian(angles, ranges):
+
+    x = np.cos(angles) * ranges
+    y = np.sin(angles) * ranges
+
+    xy = np.vstack((x, y)).T
+    return xy 
